@@ -208,12 +208,12 @@ class FileUploader(FileUploaderBase):
     display_label: bool = True
 
     def render(self):
-        label = self.name if self.display_label else ''
+        label_visibility = 'visible' if self.display_label else 'collapsed'
         return st.file_uploader(
-            label=label,
+            label=self.name,
+            label_visibility=label_visibility,
             type=self.type,
             accept_multiple_files=self.accept_multiple_files,
-            # key=self.view_key
         )
 
 
