@@ -1,7 +1,7 @@
 import dill
 from sys import argv
 from typing import Callable, Iterable, Union
-import streamlit.bootstrap
+from streamlit.web.bootstrap import run
 from streamlitfront.base import Map, dflt_convention, dispatch_funcs
 
 
@@ -12,7 +12,7 @@ def run_app(
 ):
     _funcs = dill.loads(funcs) if isinstance(funcs, bytes) else funcs
     kwargs = dict(configs=configs, convention=convention,)
-    streamlit.bootstrap.run(
+    run(
         __file__,
         args=[dill.dumps(_funcs), dill.dumps(kwargs)],
         command_line='',
